############################################################
#                                                          #
#          Figure 1.7  "Process for Boyle-Charle law"      #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################


set xrange[0.4:1]
set yrange[0.0:2]
set zrange[0:20]

set isosamples 13, 13
set view 120, 60
#set hidden3d

set xyplane at 0.0

set xlabel "{/Arial=16 T}"
unset xtics
set ylabel "{/Arial=16 v}" 
unset ytics
set zlabel "{/Arial=16 P}" 
unset ztics


TA = 0.85
VA = 0.5

TB = 0.85
VB = 1.5

VC = 1.0
TC = VC*TB/VB

dV=0.1
nV=int((VB-VA)/dV)


f(x, y)=8.31*x/y

set label 1 point pointtype 7 pointsize 1 at first TA,VA,f(TA,VA)
set label 11 "{/Arial=14 A}" at first TA,VA,f(TA,VA)+2
set label 2 point pointtype 7 pointsize 1 at first TB,VB,f(TB,VB)
set label 3 point pointtype 7 pointsize 1 at first TC,VC,f(TC,VC)
set label 31 "{/Arial=14 B}" at first TC,VC,f(TC,VC)+2


set label 41 "{/Arial=14 (I)}" at first TA+0.05,(VA+VB)*0.5,f(TA+0.05,(VA+VB)*0.5)+2
set label 51 "{/Arial=14 (II)}" at first TC,VB,f(TC,VB)+2


do for[i=1:nV]{
  set arrow from TA, VA+(i-1)*dV, f(TA, VA+(i-1)*dV) \
              to TA, VA+i*dV, f(TA, VA+i*dV) nohead linewidth 2
}
set arrow from TA, VA+(nV-2)*dV, f(TA, VA+(nV-2)*dV) to TA, VB, f(TA, VB)linewidth 2


set arrow from TB, VB, f(TB, VB) to TC, VC, f(TC, VC) linewidth 2

splot f(x, y) notitle


#--- output png format ---
set terminal png enhanced
set output "fig1_8.png"
#---------------------------------

#--- output eps format ---------------------
#set terminal postscript eps size 8cm, 6cm
#set output "fig1_8.eps"
#-------------------------------------------

replot

set output
set terminal wxt
reset
