############################################################
#                                                          #
#          Figure 3.3                                      #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################


#
set xrange[2.0:5.0]
set yrange[1.0:9.0]

unset xtics
unset ytics

set bmargin 3
set lmargin 8
xa = 2.5
xb = 4.5

array x[5] = [2.5, 3.0, 3.5, 4.0, 4.5]

set label 1 at first x[1],0.5 "x_a"
set label 2 at first x[2],0.5 "x_1"
set label 3 at first x[3],0.5 "x_2"
set label 4 at first x[4],0.5 "x_3"
set label 5 at first x[5],0.5 "x_b"

a = 1.0
b = -4.0
c = 6.0

f(x, a, b, c) = a*x**2 + b*x + c

do for[i=1:5]{
  set arrow from x[i],1.0 to x[i],f(x[i], a, b, c) nohead dt 3
}

set arrow from 2.0,f(x[2],a,b,c) to x[2],f(x[2],a,b,c) nohead dt 3
set arrow from 2.0,f(x[3],a,b,c) to x[3],f(x[3],a,b,c) nohead dt 3

set arrow from 2.0, f(x[1],a,b,c) to x[1], f(x[1],a,b,c) nohead dt 3
set arrow from 2.0, f(x[5],a,b,c) to x[5], f(x[5],a,b,c) nohead dt 3

set label 51 at first 1.8, f(x[2],a,b,c) "{/Arial f(x_1)}"
set label 52 at first 1.8, f(x[3],a,b,c) "{/Arial f(x_2)}"
set label 53 at first 1.8, f(x[1],a,b,c) "{/Arial f(x_a)}"
set label 54 at first 1.8, f(x[5],a,b,c) "{/Arial f(x_b)}"

set label 21 at first x[2]+0.22,2 "{/Symbol d}{/Arial x}"
set arrow from x[2],1.5 to x[3],1.5 heads

set label 22 at first 2.5,3.6 "{/Symbol d}{/Arial f_1}"
set arrow from 2.7,f(x[2],a,b,c) to 2.7,f(x[3],a,b,c) heads

c1 = 0.0

do for [i=1:4]{
  a1 = 2.0*a*x[i] + b
  b1 = f(x[i], a, b, c)-a1*x[i]
  g(x, a1, b1)= a1*x + b1
  set arrow from x[i], g(x[i],a1,b1)+c1 to x[i+1], g(x[i+1],a1,b1)+c1 nohead lw 2
  c1 = c1 + g(x[i+1],a1,b1)-f(x[i+1], a, b, c)
}

a1 = 2.0*a*x[1] + b
b1 = f(x[1], a, b, c)-a1*x[1]
c1 = g(x[2],a1,b1)-f(x[2], a, b, c)

a2 = 2.0*a*x[2] + b
b2 = f(x[2], a, b, c)-a2*x[2]
c2 = g(x[3],a2,b2)-f(x[3], a, b, c)

a3 = 2.0*a*x[3] + b
b3 = f(x[3], a, b, c)-a3*x[3]

g(x, an, bn)= an*x + bn

set arrow from x[2], g(x[2],a2,b2) to 5, g(5,a2,b2) nohead lw 1 dt 2
set arrow from x[2], g(x[2],a2,b2)+c1 to 5, g(5,a2,b2)+c1 nohead lw 1 dt 2
set arrow from 4.1, g(4.1,a2,b2)+c1 to 4.4, g(4.1,a2,b2)+c1 nohead
set arrow from 4.4, g(4.1,a2,b2)+c1 to 4.4, g(4.4,a2,b2)+c1 nohead
set arrow from 4.4, g(4.4,a2,b2)+c1 to 4.1, g(4.1,a2,b2)+c1 nohead
set label 31 at first 4.2, 4.6 "(df/dx)_x__1"

set arrow from x[2], f(x[2], a, b, c)+c1 to 3.8, f(x[2], a, b, c)+c1 nohead lw 1 dt 3
set arrow from x[3], f(x[3], a, b, c)+c1+c2 to 3.8, f(x[3], a, b, c)+c1+c2 nohead lw 1 dt 3
set arrow from 3.75, f(x[2], a, b, c)+c1 to 3.75, f(x[3], a, b, c)+c1+c2 heads
set label 32 at first 3.8, 3.3 "{/Arial (df/dx)_x__1}{/Symbol d}{/Arial x}"

set label 33 at first 4.3,8.0 "{/Arial A}"
set label 34 at first 4.55,7.25 "{/Arial B}"

plot f(x,a,b,c) notitle lw 2 lc rgb "black"

set terminal png enhanced
set output "bibun_sekibun.png"

#set terminal postscript eps
#set output "fig3_3.eps"

replot

set output
set size
set terminal wxt
reset
