############################################################
#                                                          #
#          Figure 3.5  "total derivative"                  #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################


set terminal wxt size 800,600

set xrange[-1:1]
set yrange[-1:1]
set zrange[-2:2]

unset xtics
unset ytics
unset ztics

set isosamples 25, 25

# view (rot around x-axis, rot around y-axis)
#set view 120, 60

#set hidden3d

set xyplane at -2.0

set xlabel "{/Arial=15 x}"
set ylabel "{/Arial=15 y}"
set zlabel "{/Arial=15 f(x,y)}"


f(x,y) = x+y
g(x,y) = (x<-0.5) ? 1/0:(y<-0.5) ? 1/0:(x>0.5) ? 1/0:(y>0.5) ? 1/0:f(x,y)

x0=-0.5
y0=-0.5

x1=0.5
y1=0.5

set label 1 point pointtype 7 pointsize 1 at first x0,y0, f(x0,y0) 
set label 2 point pointtype 7 pointsize 1 at first x1,y1, f(x1,y1) 

set arrow from x0, y0, -2 to x0, y0, f(x0, y0) nohead lw 1 lc rgb "black" dt 3
set arrow from x0, y1, -2 to x0, y1, f(x0, y1) nohead lw 1 lc rgb "black" dt 3
set arrow from x1, y0, -2 to x1, y0, f(x1, y0) nohead lw 1 lc rgb "black" dt 3
set arrow from x1, y1, -2 to x1, y1, f(x1, y1) nohead lw 1 lc rgb "black" dt 3

set arrow from x0, y0, -2 to x0, y1, -2 nohead lw 1 lc rgb "black" dt 3
set arrow from x0, y1, -2 to x1, y1, -2 nohead lw 1 lc rgb "black" dt 3
#set arrow from -1, y0, -2 to  1, y0, -2 nohead
#set arrow from -1, y1, -2 to  1, y1, -2 nohead

set arrow from x0, y0, f(x0,y0) to  x1, y0, f(x0,y0) nohead lw 1 lc rgb "black" dt 2
set arrow from x1, y0, f(x0,y0) to  x1, y1, f(x0,y0) nohead lw 1 lc rgb "black" dt 2
set arrow from x1, y0, f(x0,y0) to  x1, y1, f(x0,y1) nohead lw 1 lc rgb "black" dt 2
#set arrow from x0, y1, f(x0,y1) to  x1, y1, f(x0,y1) nohead lw 1 lc rgb "black" dt 2
set arrow from 0.26, y1, f(x0,y1) to  x1, y1, f(x0,y1) nohead lw 1 lc rgb "black" dt 2

set label 11 at first x0-0.3, y0, f(x0, y0)+0.4 "f(x_0,y_0)"
set label 12 at first x1-0.3, y1, f(x1, y1)+0.2 "f(x_0+x,y_0+y)"
#set label 12 at first x1-0.3, y1, f(x1, y1)+0.2 "f(x_0+{/Symbol d}x,y_0+{/Symbol d}y)"

set label 13 at first 0, y0,-1.7 "x"
#set label 13 at first 0, y0,-1.7 "{/Symbol d}x"
set arrow from x0, y0,-2 to  x1, y0, -2 heads
set label 14 at first x1, 0,-1.7 "y"
#set label 14 at first x1, 0,-1.7 "{/Symbol d}y"
set arrow from x1, y0, -2 to  x1, y1, -2 heads

set label 15 at first x1-0.5, y0, -0.7 "(f/x)_yx"
#set label 15 at first x1-0.5, y0, -0.7 "({/Symbol \266 }f/{/Symbol \266 }x)_y{/Symbol d}x"
set arrow from x1, y0, f(x0,y0) to x1, y0, f(x1,y0) heads
set label 16 at first x1+0.05, y1+0.05, -0.5 "(f/y)_xy"
#set label 16 at first x1+0.05, y1+0.05, -0.5 "({/Symbol \266 }f/{/Symbol \266 }y)_x{/Symbol d}y"
set arrow from x1, y1, f(x0,y0) to x1, y1, f(x0,y1) heads
set label 17 at first x1+0.05, y1+0.05, 0.5 "(f/x)_yx"
#set label 17 at first x1+0.05, y1+0.05, 0.5 "({/Symbol \266 }f/{/Symbol \266 }x)_y{/Symbol d}x"
set arrow from x1, y1, f(x0,y1) to x1, y1, f(x1,y1) heads

set arrow from x0, y0, f(x0, y0) to -1,-1, f(x0, y0) nohead
set arrow from x1, y1, f(x1, y1) to -1,-1, f(x1, y1) nohead
set arrow from -0.9, -0.9, f(x0, y0) to -0.9, -0.9, f(x1, y1) heads
set label 18 at first -0.85, -0.85, (f(x1,y1)+f(x0,y0))*0.5 "df"

splot g(x, y) notitle lw 1 lc rgb "black" dt 1



set terminal png enhanced
set output "fig3_5.png"

#set terminal postscript eps size 12cm, 9cm
#set output "fig3_5.eps"

replot

set output
set size
set terminal wxt
reset
