############################################################
#                                                          #
#          Figure 3.6  "Integral of f(x, y)"               #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################
#

set terminal wxt size 800,600

set xrange[-0.5:1.5]
set yrange[-2.0:0]
set zrange[0:2]

unset xtics
unset ytics
unset ztics

set isosamples 9, 9

# view (rot around x-axis, rot around y-axis)
#set view 120, 60

set hidden3d

set xyplane at -0.5

set xlabel "{/Arial=15 x}"
set ylabel "{/Arial=15 y}"
set zlabel "{/Arial=15 f(x,y)}"

f(x,y) = exp(-x*x-y*y)


dx=0.25
dy=0.25

xa=-0.25
ya=-1.75
xb=0.75
yb=-0.25

x1=xa+dx
x2=xa+2*dx
x3=xa+3*dx
x4=xa+4*dx

y1=ya+dy
y2=ya+2*dy
y3=ya+3*dy
y4=ya+4*dy
y5=ya+5*dy
y6=ya+6*dy


# route I

set label 1 point pointtype 7 pointsize 2 at first xa,ya,f(xa,ya)
set label 11 at first xa-0.1, ya, f(xa, ya)+0.1 "A"

set label 2 point pointtype 7 pointsize 2 at first xb,yb,f(xb,yb)
set label 12 at first xb, yb, f(xb, yb)+0.1 "B"

set arrow from xa, ya, f(xa, ya) to x1, ya, f(x1, ya) linewidth 2
set label 3 point pointtype 7 pointsize 1 at first xa+dx, ya, f(x1, ya)
set label 13 at first x1-0.08, ya, f(x1, ya)+0.1 "f_1^I"

set arrow from x1, ya, f(x1, ya) to x1, y1, f(x1, y1) linewidth 2
set label 4 point pointtype 7 pointsize 1 at first x1, y1, f(x1, y1)
set label 14 at first x1-0.08, y1, f(x1, y1)+0.1 "f_2^I"

set arrow from x1, y1, f(x1, y1) to x2, y1, f(x2, y1) linewidth 2
set label 5 point pointtype 7 pointsize 1 at first x2, y1, f(x2, y1)
set label 15 at first x2-0.08, y1, f(x2, y1)+0.1 "f_3^I"

set arrow from x2, y1, f(x2, y1) to x3, y1, f(x3, y1) linewidth 2
set label 6 point pointtype 7 pointsize 1 at first x3, y1, f(x3, y1)
set label 16 at first x3-0.08, y1, f(x3, y1)+0.1 "f_4^I"

set arrow from x3, y1, f(x3, y1) to x3, y2, f(x3, y2) linewidth 2
set label 7 point pointtype 7 pointsize 1 at first x3, y2, f(x3, y2)
set label 17 at first x3-0.08, y2, f(x3, y2)+0.1 "f_5^I"

set arrow from x3, y2, f(x3, y2) to x3, y3, f(x3, y3) linewidth 2
set label 8 point pointtype 7 pointsize 1 at first x3, y3, f(x3, y3)
set label 18 at first x3-0.08, y3, f(x3, y3)+0.1 "f_6^I"

set arrow from x3, y3, f(x3, y3) to x4, y3, f(x4, y3) linewidth 2
set arrow from x4, y3, f(x4, y3) to x4, y4, f(x4, y4) linewidth 2
set arrow from x4, y4, f(x4, y4) to x4, y5, f(x4, y5) linewidth 2
set arrow from x4, y5, f(x4, y5) to x4, y6, f(x4, y6) linewidth 2

# route II

set arrow from xa, ya, f(xa, ya) to xa, y1, f(xa, y1) linewidth 2
set label 33 point pointtype 7 pointsize 1 at first xa, y1, f(xa, y1)
set label 43 at first xa-0.09, y1, f(xa, y1)+0.1 "f_1^I^I"

set arrow from xa, y1, f(xa, y1) to xa, y2, f(xa, y2) linewidth 2
set label 34 point pointtype 7 pointsize 1 at first xa, y2, f(xa, y2)
set label 44 at first xa-0.09, y2, f(xa, y2)+0.1 "f_2^I^I"

set arrow from xa, y2, f(xa, y2) to xa, y3, f(xa, y3) linewidth 2
set label 35 point pointtype 7 pointsize 1 at first xa, y3, f(xa, y3)
set label 45 at first xa-0.09, y3, f(xa, y3)+0.1 "f_3^I^I"

set arrow from xa, y3, f(xa, y3) to x1, y3, f(x1, y3) linewidth 2
set label 36 point pointtype 7 pointsize 1 at first x1, y3, f(x1, y3)
set label 46 at first x1-0.09, y3, f(x1, y3)+0.1 "f_4^I^I"

set arrow from x1, y3, f(x1, y3) to x1, y4, f(x1, y4) linewidth 2
set label 37 point pointtype 7 pointsize 1 at first x1, y4, f(x1, y4)
set label 47 at first x1-0.09, y4, f(x1, y4)+0.1 "f_5^I^I"

set arrow from x1, y4, f(x1, y4) to x1, y5, f(x1, y5) linewidth 2
set label 38 point pointtype 7 pointsize 1 at first x1, y5, f(x1, y5)
set label 48 at first x1-0.09, y5, f(x1, y5)+0.1 "f_6^I^I"

set arrow from x1, y5, f(x1, y5) to x2, y5, f(x2, y5) linewidth 2
set arrow from x2, y5, f(x2, y5) to x2, y6, f(x2, y6) linewidth 2
set arrow from x2, y6, f(x2, y6) to x3, y6, f(x3, y6) linewidth 2
set arrow from x3, y6, f(x3, y6) to x4, y6, f(x4, y6) linewidth 2

splot f(x, y) notitle lw 1 lc rgb "black" dt 1



#set terminal png enhanced size 800,600
#set output "fig3_6.png"

#set terminal postscript eps size 12cm, 9cm
#set output "fig3_6.eps"

replot

set output
set size
set terminal wxt
reset
