############################################################
#                                                          #
#          Figure 4.9  "Mayer cycle"                       #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################

set xrange[0.4:1]
set yrange[0.0:2]
set zrange[0:20]

set isosamples 13, 13
set view 120, 60, 1, 1.5
#set hidden3d

set xyplane at 0.0

set xlabel "{/Arial T}"
unset xtics
set ylabel "{/Arial v}" 
unset ytics
set zlabel "{/Arial P}" 
unset ztics


TA = 0.95
VA = 0.667

TB = 0.95
VB = 1.333

TC = VA*TB/VB
VC = VA

dV=0.1
V1 = VA+dV
V2 = V1+dV
V3 = V2+dV
V4 = V3+dV
V5 = V4+dV
V6 = V5+dV


f(x, y)=8.31*x/y

set label 1 point pointtype 7 pointsize 1 at first TA,VA,f(TA,VA)
set label 11 "{/Arial=15 A}" at first TA,VA,f(TA,VA)+2
set label 2 point pointtype 7 pointsize 1 at first TB,VB,f(TB,VB)
set label 21 "{/Arial=15 B}" at first TB,VB,f(TB,VB)+2
set label 3 point pointtype 7 pointsize 1 at first TC,VC,f(TC,VC)
set label 31 "{/Arial=15 C}" at first TC,VC,f(TC,VC)+2

set arrow from TA, VA, f(TA, VA) to TA, V1, f(TA, V1) nohead linewidth 2
set arrow from TA, V1, f(TA, V1) to TA, V2, f(TA, V2) nohead linewidth 2
set arrow from TA, V2, f(TA, V2) to TA, V3, f(TA, V3) nohead linewidth 2
set arrow from TA, V3, f(TA, V3) to TA, V4, f(TA, V4) nohead linewidth 2
set arrow from TA, V4, f(TA, V4) to TB, VB, f(TB, VB) linewidth 2

set arrow from TB, VB, f(TB, VB) to TC, VC, f(TC, VC) linewidth 2
set arrow from TC, VC, f(TC, VC) to TA, VA, f(TA, VA) linewidth 2

splot f(x, y) notitle lw 1 lc rgb "black" dt 1



set terminal png enhanced
set output "fig4_9.png"

#set terminal postscript eps size 8cm, 6cm
#set output "fig4_9.eps"

replot

set output
set terminal wxt
reset
