############################################################
#                                                          #
#          Figure 5.2  "P-v-T of Carnot cycle"             #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################

set xrange[0.7:1.5]
set yrange[0.2:2]
set zrange[0:20]

set isosamples 13, 13
set view 120, 80, 1, 1.2
#set hidden3d

set xyplane at 0.0

set xlabel "{/Arial=15 T}"
unset xtics
set ylabel "{/Arial=15 v}" 
unset ytics
set zlabel "{/Arial=15 P}" 
unset ztics

VA = 0.667
TA = 1.25

VB = 1.167
TB = TA

VC = 1.75
TC = TB*(VB/VC)**0.667

TD = TC
VD = TA/TD*VA**0.667


f(x, y)=8.31*x/y

dV=0.1

V11 = VA+dV
T11 = TA
V12 = V11+dV
T12 = TA
V13 = V12+dV
T13 = TA
V14 = V13+dV
T14 = TA

V21 = VB+dV
T21 = TB*(VB/V21)**0.667
V22 = V21+dV
T22 = TB*(VB/V22)**0.667
V23 = V22+dV
T23 = TB*(VB/V23)**0.667
V24 = V23+dV
T24 = TB*(VB/V24)**0.667

V31 = VC-dV
T31 = TC
V32 = V31-dV
T32 = TC
V33 = V32-dV
T33 = TC
V34 = V33-dV
T34 = TC
V35 = V34-dV
T35 = TC
V36 = V35-dV
T36 = TC

V41 = VD-dV
T41 = TD*(VD/V41)**0.667
V42 = V41-dV
T42 = TD*(VD/V42)**0.667
V43 = V42-dV
T43 = TD*(VD/V43)**0.667
V44 = V43-dV
T44 = TD*(VD/V44)**0.667

set label 1 point pointtype 7 pointsize 1 at first TA, VA, f(TA, VA)
set label 11 "{/Arial=15 A}" at first TA, VA, f(TA, VA)+2
set label 2 point pointtype 7 pointsize 1 at first TB, VB, f(TB, VB)
set label 21 "{/Arial=15 B}" at first TB, VB, f(TB, VB)+2
set label 3 point pointtype 7 pointsize 1 at first TC, VC, f(TC, VC)
set label 31 "{/Arial=15 C}" at first TC, VC, f(TC, VC)+2
set label 4 point pointtype 7 pointsize 1 at first TD, VD, f(TD, VD)
set label 41 "{/Arial=15 D}" at first TD, VD, f(TD, VD)+2

set arrow from TA, VA, f(TA, VA)     to T11, V11, f(T11, V11) nohead linewidth 2
set arrow from T11, V11, f(T11, V11) to T12, V12, f(T12, V12) nohead linewidth 2
set arrow from T12, V12, f(T12, V12) to T13, V13, f(T13, V13) nohead linewidth 2
set arrow from T13, V13, f(T13, V13) to T14, V14, f(T14, V14) nohead linewidth 2
set arrow from T14, V14, f(T14, V14) to TB, VB, f(TB, VB) nohead linewidth 2

set arrow from TB, VB, f(TB, VB)     to T21, V21, f(T21, V21) nohead linewidth 2
set arrow from T21, V21, f(T21, V21) to T22, V22, f(T22, V22) nohead linewidth 2
set arrow from T22, V22, f(T22, V22) to T23, V23, f(T23, V23) nohead linewidth 2
set arrow from T23, V23, f(T23, V23) to T24, V24, f(T24, V24) nohead linewidth 2
set arrow from T24, V24, f(T24, V24) to TC, VC, f(TC, VC) nohead linewidth 2

set arrow from TC, VC, f(TC, VC)     to T31, V31, f(T31, V31) nohead linewidth 2
set arrow from T31, V31, f(T31, V31) to T32, V32, f(T32, V32) nohead linewidth 2
set arrow from T32, V32, f(T32, V32) to T33, V33, f(T33, V33) nohead linewidth 2
set arrow from T33, V33, f(T33, V33) to T34, V34, f(T34, V34) nohead linewidth 2
set arrow from T34, V34, f(T34, V34) to T35, V35, f(T35, V35) nohead linewidth 2
set arrow from T35, V35, f(T35, V35) to T36, V36, f(T36, V36) nohead linewidth 2
set arrow from T36, V36, f(T36, V36) to TD, VD, f(TD, VD) nohead linewidth 2

set arrow from TD, VD, f(TD, VD)     to T41, V41, f(T41, V41) nohead linewidth 2
set arrow from T41, V41, f(T41, V41) to T42, V42, f(T42, V42) nohead linewidth 2
set arrow from T42, V42, f(T42, V42) to T43, V43, f(T43, V43) nohead linewidth 2
set arrow from T43, V43, f(T43, V43) to TA, VA, f(TA, VA) nohead linewidth 2

set label 51 "{/Arial=15 I}" at first T12, V12, f(T12, V12)+2
set label 52 "{/Arial=15 II}" at first T23, V23, f(T23, V23)+2
set label 53 "{/Arial=15 III}" at first T35, V35, f(T35, V35)-3
set label 54 "{/Arial=15 VI}" at first T43, V43-0.1, f(T43, V43)-5


splot f(x, y) notitle lw 1 lc rgb "black" dt 1



set terminal png enhanced
set output "fig5_2.png"

#set terminal postscript eps size 8cm, 6cm
#set output "fig5_2.eps"
replot

set output
set terminal wxt
reset
