############################################################
#                                                          #
#          Figure 8.2  "H, S, G of H2O"                    #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################

reset
#set terminal wxt

set terminal png enhanced
set output "fig8_2.png"

#set terminal postscript eps size 9cm,12cm
#set output "fig8_2.eps"


T0=173.0
H0=-300000.0
S0=25.2

CPS=38.0
CPL=76.0
CPG=34.0

dHm=6000.0
dHb=40000.0

Tm=273.0
Tb=373.0

dSm=dHm/Tm
dSb=dHb/Tb

HS(x)=(x<=Tm) ?                     CPS*(x-T0):1/0
HL(x)=(Tm<=x && x<=Tb) ? HS(Tm)+dHm+CPL*(x-Tm):1/0
HG(x)=(Tb<=x) ?          HL(Tb)+dHb+CPG*(x-Tb):1/0

SS(x)=(x<=Tm) ?                     CPS*log(x/T0):1/0
SL(x)=(Tm<=x && x<=Tb) ? SS(Tm)+dSm+CPL*log(x/Tm):1/0
SG(x)=(Tb<=x) ?          SL(Tb)+dSb+CPG*log(x/Tb):1/0

GS(x)=(x<=Tm) ?          HS(x)-x*SS(x):1/0
GL(x)=(Tm<=x && x<=Tb) ? HL(x)-x*SL(x):1/0
GG(x)=(Tb<=x) ?          HG(x)-x*SG(x):1/0

set multiplot

set lmargin at screen 0.20
set rmargin at screen 0.70
set bmargin at screen 0.64
set tmargin at screen 0.91

set xrange [Tm-100:Tb+100]
set yrange [-5000:70000]

set format x ""
set format y ""

set ylabel "{/Arial H}"

set arrow from Tm,HS(Tm) to Tm,HL(Tm) nohead
set arrow from Tb,HL(Tb) to Tb,HG(Tb) nohead

plot HS(x) notitle, HL(x) notitle, HG(x) notitle

unset arrow

set lmargin at screen 0.20
set rmargin at screen 0.70
set bmargin at screen 0.37
set tmargin at screen 0.64

set yrange [-50:200]

set format x ""
set format y ""

set ylabel "{/Arial S}"

set arrow from Tm,SS(Tm) to Tm,SL(Tm) nohead
set arrow from Tb,SL(Tb) to Tb,SG(Tb) nohead

plot SS(x) notitle, SL(x) notitle, SG(x) notitle

unset arrow

set lmargin at screen 0.20
set rmargin at screen 0.70
set bmargin at screen 0.10
set tmargin at screen 0.37

set yrange [-25000:2000]

set format x "%.0f"
set format y ""

set ylabel "{/Arial G}"

set xlabel "{/Arial T[K]}"

set arrow from Tm,GS(Tm)-12000 to Tm, GS(Tm)-2000
set arrow from Tb,GL(Tb)-12000 to Tb, GL(Tb)-2000
set label 1 at first Tm-5, GS(Tm)-15000 "{/Arial T_m}"
set label 2 at first Tb-5, GL(Tb)-15000 "{/Arial T_b}"

plot GS(x) notitle, GL(x) notitle, GG(x) notitle

unset arrow
set label 1 ""
set label 2 ""

unset multiplot

set output
set terminal wxt
reset


