############################################################
#                                                          #
#     Figure 8.3  "Van der Waals equation of Ar gas"       #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################

set terminal wxt size 800,600

a = 0.1355
b = 32.01*10**-6

TC = 150.7

R = 8.314

T1 = 140.0
#P1(x) = (x>b) ? R*T1/(x-b) - a/x**2: 1/0
#P1(x) = (x>b) ? (R*T1/(x-b) - a/x**2)*10**-6: 1/0
P1(x) = ((x*10**-5)>b) ? (R*T1/((x*10**-5)-b) - a/(x*10**-5)**2)*10**-6: 1/0

T2 = TC
#P2(x) = (x>b) ? R*T2/(x-b) - a/x**2: 1/0
#P2(x) = (x>b) ? (R*T2/(x-b) - a/x**2)*10**-6: 1/0
P2(x) = ((x*10**-5)>b) ? (R*T2/((x*10**-5)-b) - a/(x*10**-5)**2)*10**-6: 1/0

T3 = 160.0
#P3(x) = (x>b) ? R*T3/(x-b) - a/x**2: 1/0
#P3(x) = (x>b) ? (R*T3/(x-b) - a/x**2)*10**-6: 1/0
P3(x) = ((x*10**-5)>b) ? (R*T3/((x*10**-5)-b) - a/(x*10**-5)**2)*10**-6: 1/0

set samples 1000

#set xrange [1.0*10**-5:2.4*10**-4]
set xrange [0.0:25.0]
#set yrange [2*10**6:9*10**6]
set yrange [1.0:10.0]

#set format x "%2.1tx10^{%L}"
#set format y "%2.0tx10^{%L}"

set format x "%.1f"
set format y "%.1f"

#set xlabel "{/Arial v (m^3/mol)}"
set xlabel "{/Arial=15 v (x10^-^3 m^3/mol)}"
#set ylabel "{/Arial P [Pa]
set ylabel "{/Arial=15 P (MPa)}"

set label 1 at first 20.0,9.0 "{/Arial=15 T_C=150.7 K}"
set label 2 at first 12.0,6.0 "{/Arial=15 T_C+10 K}"
set label 3 at first 12.0,5.0 "{/Arial=15 T_C}"
set label 4 at first 12.0,4.0 "{/Arial=15 T_C-10 K}"


set arrow 1 from 5.0,2.5 to 7.5,3.2  lw 1 lc rgb "black" dt 1
set arrow 2 from 15.0,2.0 to 12.5,3.7  lw 1 lc rgb "black" dt 1
set arrow 3 from 6.25,3.5 to 20.5, 3.5 nohead lw 1 lc rgb "black" dt 2

set label 5 at first 4.5,2.0 "{/Arial=15 S_1}"
set label 6 at first 15.5,2.0 "{/Arial=15 S_2}"

plot P1(x) notitle lw 1 lc rgb "black" dt 1, \
     P2(x) notitle lw 1 lc rgb "black" dt 1, \
     P3(x) notitle lw 1 lc rgb "black" dt 1


set terminal png enhanced
set output "fig8_3.png"

#set terminal postscript eps
#set output "fig8_3.eps"

replot

set terminal wxt
set output

reset

