############################################################
#                                                          #
#      Figure 8.5  "P & F of van der Waals equation"       #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################

set terminal wxt

#set terminal png enhanced
#set output "fig8_5.png"

#set terminal postscript eps
#set output "fig8_5.eps"


T=0.8

v1=0.517411
v3=4.17283
PA=0.383347

P(x)=8.0*T/(3.0*x-1.0)-3.0/x**2
f(x)=-8.0*T/3.0*log(3.0*x-1.0)-3.0/x

a=(f(v3)-f(v1))/(v3-v1)
b=(v3*f(v1)-v1*f(v3))/(v3-v1)

set samples 10000



set multiplot

set lmargin at screen 0.20
set rmargin at screen 0.70
set bmargin at screen 0.55
set tmargin at screen 0.90

set xrange [0.0:6.0]
set yrange[-0.5:1.0]

set format x ""
set format y "%.1f"

set ylabel "{/Arial P(v)/P_C}"

set label 1 at first 4.8, 0.8 "{/Arial T/T_C=0.8}"
set label 2 at first 2.0,0.3 "{/Arial P_A/P_C=0.383}" 

set arrow from v1+0.3, P(v1)+0.2 to v1, P(v1)
set label 3 at first v1+0.35, P(v1)+0.25 "{/Arial v_L}"

set arrow from v3-0.3, P(v3)-0.2 to v3, P(v3)
set label 4 at first v3-0.35, P(v3)-0.25 "{/Arial v_G}"

plot P(x) notitle lw 1 lc rgb "black" dt 1,\
     PA notitle lw 1 lc rgb "black" dt 2

unset label 1
unset label 2
unset label 3
unset label 4
unset arrow

set lmargin at screen 0.20
set rmargin at screen 0.70
set bmargin at screen 0.15
set tmargin at screen 0.55

set yrange[-6.5:-3.5]

set format x "%.1f"
set format y ""

set ylabel "{/Arial f(v)}"
set xlabel "{/Arial v/v_C}"


set arrow from v1, f(v1)-0.5 to v1, f(v1)
set label 1 at first v1, f(v1)-0.65 "{/Arial v_L}"

set arrow from v3, f(v3)+0.5 to v3, f(v3)
set label 2 at first v3, f(v3)+0.65 "{/Arial v_G}"

plot f(x) notitle lw 1 lc rgb "black" dt 1,\
     a*x+b notitle lw 1 lc rgb "black" dt 2

unset label 1
unset label 2
unset arrow

unset multiplot


set terminal wxt
set output
reset
