############################################################
#                                                          #
#          Figure 10.10  "G of regular solution"           #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################


unset multiplot

#set terminal wxt size 600,900

set terminal png enhanced size 600,900
set output "fig10_10.png"

#set terminal postscript eps size 8cm, 12cm
#set output "fig10_10.eps"


R=8.31
G1=-5000.0
G2=-7000.0

T1=1200.0
T2=700.0

eps=-5000.0

GS(x)=G1*(1.0-x)+G2*x+eps*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x))
GL(x)=G1*(1.0-x)+G2*x+eps*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x)) \
      +R*(T1-T)*(1.0-x)+R*(T2-T)*x

dGS(x)=-G1+G2+eps*(1.0-x)-eps*x+R*T*log(x/(1-x))
dGL(x)=-G1+G2+eps*(1.0-x)-eps*x+R*T*log(x/(1-x))+R*(T2-T1)


set multiplot

set xrange[0.0:1.0]
set yrange[-17000:-3000]
set ytics 4000
set ylabel "{/Arial G(J)}"

#-----------------------------------------------------------------

set lmargin at screen 0.20
set rmargin at screen 0.80
set bmargin at screen 0.70
set tmargin at screen 0.90

T=1100.0

set format x ""

h=0.01

xa=0.1
xb=0.1

delta = 10.0

while( abs(delta)>0.001){

  f(x)=dGL(x)-dGS(xa)

  while( abs(f(xb))>0.001 ){
    df=f(xb+h)-f(xb-h)/(2*h)
    xbnew = xb-f(xb)/df
    xb = xbnew
  }

  a=dGL(xb)
  b=GL(xb)-a*xb

  delta = (a*xa+b) - GS(xa)

  xa = xa+delta*0.0001

#  print b
#  print delta
#  print xa

}

#set label 98 sprintf("xa=%10.5f a=%10.5f", xa, dGS(xa)) at graph 0.02,0.10
#set label 99 sprintf("xb=%10.5f a=%10.5f", xb, dGL(xb)) at graph 0.02,0.05

set arrow from xa, GS(xa)-2000 to xa,GS(xa)
set arrow from xb, GL(xb)-2000 to xb,GL(xb)
set label 21 at first xa-0.02, GS(xa)-2700 "{/Arial x_S}"
set label 22 at first xb-0.02, GS(xb)-2700 "{/Arial x_L}"

set label 31 at first 0.8, GS(0.8)+1500 "{/Arial G_S}"
set label 41 at first 0.8, GL(0.8)-1000 "{/Arial G_L}"

set label 11 at first 0.7, -4500 sprintf("%.0f(K)", T)

plot GS(x) notitle lw 1 lc rgb "black" dt 1, \
     GL(x) notitle lw 1 lc rgb "black" dt 1, \
     a*x+b notitle lw 1 lc rgb "black" dt 1

a1=a
b1=b
xa1=xa
xb1=xb

print "T:",T
print "a:",a1
print "b:",b1
print "xS:", xa1
print "xL:", xb1
print ""

unset arrow
unset label 11
unset label 21
unset label 22
unset label 31
unset label 32

#------------------------------------------------------------------------

set lmargin at screen 0.20
set rmargin at screen 0.80
set bmargin at screen 0.50
set tmargin at screen 0.70

T=1000.0

set format x ""

xa=0.1
xb=0.1

delta = 10.0

while( abs(delta)>0.001){

  f(x)=dGL(x)-dGS(xa)

  while( abs(f(xb))>0.001 ){
    df=f(xb+h)-f(xb-h)/(2*h)
    xbnew = xb-f(xb)/df
    xb = xbnew
  }

  a=dGL(xb)
  b=GL(xb)-a*xb

  delta = (a*xa+b) - GS(xa)

  xa = xa+delta*0.0001

#  print b
#  print delta
#  print xa

}

#set label 98 sprintf("xa=%10.5f a=%10.5f", xa, dGS(xa)) at graph 0.02,0.10
#set label 99 sprintf("xb=%10.5f a=%10.5f", xb, dGL(xb)) at graph 0.02,0.05

set arrow from xa, GS(xa)-2000 to xa,GS(xa)
set arrow from xb, GL(xb)-2000 to xb,GL(xb)
set label 21 at first xa-0.02, GS(xa)-2700 "{/Arial x_S}"
set label 22 at first xb-0.02, GS(xb)-2700 "{/Arial x_L}"

set label 31 at first 0.8, GS(0.8)+1500 "{/Arial G_S}"
set label 41 at first 0.8, GL(0.8)-1000 "{/Arial G_L}"

set label 11 at first 0.7, -4500 sprintf("%.0f(K)", T)

plot GS(x) notitle lw 1 lc rgb "black" dt 1, \
     GL(x) notitle lw 1 lc rgb "black" dt 1, \
     a*x+b notitle lw 1 lc rgb "black" dt 1

a2=a
b2=b
xa2=xa
xb2=xb

print "T:",T
print "a:",a2
print "b:",b2
print "xS:", xa2
print "xL:", xb2
print ""

unset arrow
unset label 11
unset label 21
unset label 22
unset label 31
unset label 32

#-----------------------------------------------------------------------------


set lmargin at screen 0.20
set rmargin at screen 0.80
set bmargin at screen 0.30
set tmargin at screen 0.50

T=900.0

set format x ""

xa=0.1
xb=0.1

delta = 10.0

while( abs(delta)>0.001){

  f(x)=dGL(x)-dGS(xa)

  while( abs(f(xb))>0.001 ){
    df=f(xb+h)-f(xb-h)/(2*h)
    xbnew = xb-f(xb)/df
    xb = xbnew
  }

  a=dGL(xb)
  b=GL(xb)-a*xb

  delta = (a*xa+b) - GS(xa)

  xa = xa+delta*0.0001

#  print b
#  print delta
#  print xa

}

#set label 98 sprintf("xa=%10.5f a=%10.5f", xa, dGS(xa)) at graph 0.02,0.10
#set label 99 sprintf("xb=%10.5f a=%10.5f", xb, dGL(xb)) at graph 0.02,0.05

set arrow from xa, GS(xa)-2000 to xa,GS(xa)
set arrow from xb, GL(xb)-2000 to xb,GL(xb)
set label 21 at first xa-0.02, GS(xa)-2700 "{/Arial x_S}"
set label 22 at first xb-0.02, GS(xb)-2700 "{/Arial x_L}"

set label 31 at first 0.2, GS(0.2)-1500 "{/Arial G_S}"
set label 41 at first 0.2, GL(0.2)+1000 "{/Arial G_L}"

set label 11 at first 0.7, -4500 sprintf("%.0f(K)", T)

plot GS(x) notitle lw 1 lc rgb "black" dt 1, \
     GL(x) notitle lw 1 lc rgb "black" dt 1, \
     a*x+b notitle lw 1 lc rgb "black" dt 1

a3=a
b3=b
xa3=xa
xb3=xb

print "T:",T
print "a:",a3
print "b:",b3
print "xS:", xa3
print "xL:", xb3
print ""

unset arrow
unset label 11
unset label 21
unset label 22
unset label 31
unset label 32

#-----------------------------------------------------------------------------

set lmargin at screen 0.20
set rmargin at screen 0.80
set bmargin at screen 0.10
set tmargin at screen 0.30

T=800.0

set xlabel "{/Arial x_B}"
set format x "%.1f"

xa=0.1
xb=0.1

delta = 10.0

while( abs(delta)>0.001){

  f(x)=dGL(x)-dGS(xa)

  while( abs(f(xb))>0.001 ){
    df=f(xb+h)-f(xb-h)/(2*h)
    xbnew = xb-f(xb)/df
    xb = xbnew
  }

  a=dGL(xb)
  b=GL(xb)-a*xb

  delta = (a*xa+b) - GS(xa)

  xa = xa+delta*0.0001

#  print b
#  print delta
#  print xa

}

#set label 98 sprintf("xa=%10.5f a=%10.5f", xa, dGS(xa)) at graph 0.02,0.10
#set label 99 sprintf("xb=%10.5f a=%10.5f", xb, dGL(xb)) at graph 0.02,0.05

set arrow from xa, GS(xa)-2000 to xa,GS(xa)
set arrow from xb, GL(xb)-2000 to xb,GL(xb)
set label 21 at first xa-0.02, GS(xa)-2700 "{/Arial x_S}"
set label 22 at first xb-0.02, GS(xb)-2700 "{/Arial x_L}"

set label 31 at first 0.2, GS(0.2)-1500 "{/Arial G_S}"
set label 41 at first 0.2, GL(0.2)+1000 "{/Arial G_L}"

set label 11 at first 0.7, -4500 sprintf("%.0f(K)", T)

plot GS(x) notitle lw 1 lc rgb "black" dt 1, \
     GL(x) notitle lw 1 lc rgb "black" dt 1, \
     a*x+b notitle lw 1 lc rgb "black" dt 1

a4=a
b4=b
xa4=xa
xb4=xb

print "T:",T
print "a:",a4
print "b:",b4
print "xS:", xa4
print "xL:", xb4
print ""

unset arrow
unset label 11
unset label 21
unset label 22
unset label 31
unset label 32

#-----------------------------------------------------------------------------



unset multiplot

set output
set terminal wxt

reset
