############################################################
#                                                          #
#           Figure 10.11  "G of solid solution"            #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################

unset multiplot

#set terminal wxt size 800,1000

set terminal png enhanced size 800,1000
set output "fig2_4.png"

#set terminal postscript eps size 8cm, 10cm
#set output "fig10_11.eps"

R=8.31
G1=-5000.0
G2=-7000.0

T1=1200.0
T2=700.0

eps=-5000.0

GS(x)=G1*(1.0-x)+G2*x+eps*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x))
GL(x)=G1*(1.0-x)+G2*x+eps*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x)) \
      +R*(T1-T)*(1.0-x)+R*(T2-T)*x

dGS(x)=-G1+G2+eps*(1.0-x)-eps*x+R*T*log(x/(1-x))
dGL(x)=-G1+G2+eps*(1.0-x)-eps*x+R*T*log(x/(1-x))+R*(T2-T1)


set multiplot

set xrange[0.0:1.0]
set yrange[-17000:-3000]
set ytics 4000
set ylabel "{/Arial G(J)}"

set lmargin at screen 0.20
set rmargin at screen 0.80
set tmargin at screen 0.90
set bmargin at screen 0.50


T0 = 1000
T = T0

set format x ""

h = 0.01
xa0 = 0.1
xb0 = 0.1

delta = 10.0

while( abs(delta)>0.001){

f(x)=dGL(x)-dGS(xa0)

  while( abs(f(xb0))>0.001 ){
    df=(f(xb0+h)-f(xb0-h))/(2*h)
    xb0new = xb0-f(xb0)/df
    xb0 = xb0new
  }

  a0=dGL(xb0)
  b0=GL(xb0)-a0*xb0

  delta = (a0*xa0+b0) - GS(xa0)

  xa0 = xa0+delta*0.0001

#  print a0, b0, xa0, xb0

}

set arrow from xa0, GS(xa0)-2000 to xa0,GS(xa0)
set arrow from xb0, GL(xb0)-2000 to xb0,GL(xb0)
set label 21 at first xa0-0.02, GS(xa0)-2700 "{/Arial x_S}"
set label 22 at first xb0-0.02, GS(xb0)-2700 "{/Arial x_L}"

set label 31 at first 0.8, GS(0.8)+1500 "{/Arial G_S}"
set label 41 at first 0.8, GL(0.8)-1000 "{/Arial G_L}"

set label 11 at first 0.7, -4500 sprintf("%.0f(K)", T)
  
plot GS(x) notitle lw 1 lc rgb "black" dt 1, \
     GL(x) notitle lw 1 lc rgb "black" dt 1, \
     a0*x+b0 notitle lw 1 lc rgb "black" dt 1


unset arrow
unset label 11
unset label 21
unset label 22
unset label 31
unset label 32


#----------------------------------------------

set lmargin at screen 0.20
set rmargin at screen 0.80
set tmargin at screen 0.50
set bmargin at screen 0.10

dT = (T2-T1)/20.0

array a[25]
array b[25]
array xa[25]
array xb[25]
array Temp[25]

h=0.01

set yrange[650:1250]
set ytics 100
set ylabel "{/Arial T(K)}"

set xlabel "{/Arial x_B}"
set format x "%.1f"

xa0 = 0.05
xb0 = 0.05

xa[1] = 0.0
xb[1] = 0.0
Temp[1] = T1

do for[i=2:20]{

  T = T1+dT*(i-1)
  Temp[i] = T

  delta = 10.0

  while( abs(delta)>0.001){

    f(x)=dGL(x)-dGS(xa0)

    while( abs(f(xb0))>0.001 ){
      df=(f(xb0+h)-f(xb0-h))/(2*h)
      xb0new = xb0-f(xb0)/df
      xb0 = xb0new
    }

    a0=dGL(xb0)
    b0=GL(xb0)-a0*xb0

    delta = (a0*xa0+b0) - GS(xa0)

    xa0 = xa0+delta*0.0001

  }

  a[i] = a0
  b[i] = b0
  xa[i] = xa0
  xb[i] = xb0

  print Temp[i],xa[i], xb[i]

#  set label i+100 point pointtype 7 pointsize 1 at first xa[i],Temp[i]
#  set label i+200 point pointtype 7 pointsize 1 at first xb[i],Temp[i]

  set arrow from xa[i-1], Temp[i-1] to xa[i], Temp[i] nohead
  set arrow from xb[i-1], Temp[i-1] to xb[i], Temp[i] nohead


}

set arrow from xa[20], Temp[20] to 1.0, T2 nohead
set arrow from xb[20], Temp[20] to 1.0, T2 nohead

set arrow from xa[9], Temp[9]-100 to xa[9], Temp[9]
set arrow from xb[9], Temp[9]+100 to xb[9], Temp[9]

set label 31 at first xa[9], Temp[9]-150 "{/Arial x_S}"
set label 41 at first xb[9], Temp[9]+150 "{/Arial x_L}"

plot 0 notitle lw 1 lc rgb "black" dt 1, \
     T0 notitle lw 1 lc rgb "black" dt 1



unset multiplot


set output
set terminal wxt

reset
