############################################################
#                                                          #
#          Figure 10.12  "G of eutectic alloy"             #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################

unset multiplot

#set terminal wxt size 600,900

set terminal png enhanced size 600,900
set output "fig10_12.png"

#set terminal postscript eps size 8cm,12cm
#set output "fig10_12.eps"

R=8.314
G1=-15000.0
G2=-17000.0

T1=1200.0
T2=1000.0

epsS=20000.0
#epsL=5000.0
epsL=0.0

GS(x)=G1*(1.0-x)+G2*x+epsS*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x))
GL(x)=G1*(1.0-x)+G2*x+epsL*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x)) \
       +R*(T1-T)*(1.0-x)+R*(T2-T)*x

dGS(x)=-G1+G2+epsS*(1.0-x)-epsS*x+R*T*log(x/(1-x))
dGL(x)=-G1+G2+epsL*(1.0-x)-epsL*x+R*T*log(x/(1-x))+R*(T2-T1)


set multiplot

set xrange[0.0:1.0]
set ytics 2000
set ylabel "{/Arial G(J)}"

Teu=656.5

array Temp[4] = [1100.0, 850.0, Teu, 600.0]
array yrmin[4] = [-23000,-21000,-19000,-19000]
array yrmax[4] = [-15000,-13000,-11000,-11000]
array lx[4] = [0.3, 0.6, 0.5, 0.5]

height=0.2

set lmargin at screen 0.20
set rmargin at screen 0.80
tmarg = 0.9

h=0.001

do for[i=1:4]{

  a0=0.0
  b0=0.0
  a1=0.0
  b1=0.0
  a2=G2-G1
  b2=0.0

  set tmargin at screen (tmarg - height*(i-1))
  set bmargin at screen (tmarg - height*i)

  T = Temp[i]

  if(i<4){
    set format x ""
  }else{
    set format x "%.1f"
  }
  

  if(T<T1){

    xa0 = 0.01
    xb0 = 0.1

    delta = 10.0

    while( abs(delta)>0.001 ){

      f(x)=dGL(x)-dGS(xa0)

      while( abs(f(xb0))>0.001 ){
        df=(f(xb0+h)-f(xb0-h))/(2*h)
        xb0new = xb0-f(xb0)/df
        xb0 = xb0new
      }

      a0=dGL(xb0)
      b0=GL(xb0)-a0*xb0

      delta = (a0*xa0+b0) - GS(xa0)

      xa0 = xa0+delta*0.00001

    }

    set arrow from xa0, GS(xa0)-1500 to xa0, GS(xa0)
    set arrow from xb0, GL(xb0)-1500 to xb0, GL(xb0)

#    print T,"#1", a0, b0, xa0, xb0
  
  }

  if(T<T2){

    xa1 = 0.99
    xb1 = 0.95

    delta = 10.0

    while( abs(delta)>0.001 ){

      f(x)=dGL(x)-dGS(xa1)

      while( abs(f(xb1))>0.001 ){
        df=(f(xb1+h)-f(xb1-h))/(2*h)
        xb1new = xb1-f(xb1)/df
        xb1 = xb1new
      }

      a1=dGL(xb1)
      b1=GL(xb1)-a1*xb1

      delta = (a1*xa1+b1) - GS(xa1)

      xa1 = xa1-delta*0.00001

#      print a1, b1, xa1, xb1

    }

    set arrow from xa1, GS(xa1)-1500 to xa1, GS(xa1)
    set arrow from xb1, GL(xb1)-1500 to xb1, GL(xb1)


  }


  if(T<Teu){

    f(x)=dGS(x)-a2

    xa2 = 0.01
    while( abs(f(xa2))>0.001 ){
      df=(f(xa2+h)-f(xa2-h))/(2*h)
      xa2new = xa2-f(xa2)/df
      xa2 = xa2new
    }
    b2=GS(xa2)-a2*xa2

    xb2 = 0.99
    while( abs(f(xb2))>0.001 ){
      df=(f(xb2+h)-f(xb2-h))/(2*h)
      xb2new = xb2-f(xb2)/df
      xb2 = xb2new
    }

    unset arrow

    set arrow from xa2, GS(xa2)-1500 to xa2, GS(xa2)
    set arrow from xb2, GS(xb2)-1500 to xb2, GS(xb2)



#      print a2, b2, xa2, xb2
  }


  if(i<4){
    set xlabel ""
  }else{
    set xlabel "{/Arial x_B}"
  }

  set yrange[yrmin[i]:yrmax[i]]

  set label 1 at graph 0.8,0.8 sprintf("%.0f (K)", T);

  set label 2 at first lx[i], GS(lx[i])+500 "{/Arial G_S}"
  set label 3 at first lx[i], GL(lx[i])+500 "{/Arial G_L}"

  plot GS(x) notitle lw 1 lc rgb "black" dt 1, \
     GL(x) notitle lw 1 lc rgb "black" dt 1, \
     a0*x+b0 notitle lw 1 lc rgb "black" dt 1,\
     a1*x+b1 notitle lw 1 lc rgb "black" dt 1, \
     a2*x+b2 notitle lw 1 lc rgb "black" dt 1

  unset label 1
  unset label 2
  unset arrow


}

unset multiplot


set output
set terminal wxt

reset
