############################################################
#                                                          #
#     Figure 10.13  "phase diagram of eutectic system"     #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################

# phase diagram of eutectic alloy
#

unset multiplot

set terminal wxt size 640,480

#set terminal png enhanced size 640,480
#set output "fig10_13.png"

#set terminal postscript eps
#set output "fig10_13.eps"


R=8.314
G1=-15000.0
G2=-17000.0

T1=1200.0
T2=1000.0

epsS=20000.0
#epsL=5000.0
epsL=0.0


GS(x)=G1*(1.0-x)+G2*x+epsS*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x))
GL(x)=G1*(1.0-x)+G2*x+epsL*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x)) \
       +R*(T1-T)*(1.0-x)+R*(T2-T)*x

dGS(x)=-G1+G2+epsS*(1.0-x)-epsS*x+R*T*log(x/(1-x))
dGL(x)=-G1+G2+epsL*(1.0-x)-epsL*x+R*T*log(x/(1-x))+R*(T2-T1)

Tmax = 1300
Tmin = 500
dT = 1
nT = int((Tmax-Tmin)/dT)

set xrange[0.0:1.0]
set yrange[Tmin:Tmax]
set ytics 100
set xlabel "{/Arial x_B}"
set ylabel "{/Arial T(K)}"

Teu=656.5

array L1x[nT]
array L1T[nT]
array S1x[nT]
array S1T[nT]
array L2x[nT]
array L2T[nT]
array S2x[nT]
array S2T[nT]
array S3x[nT]
array S3T[nT]
array S4x[nT]
array S4T[nT]

height=0.2

set lmargin at screen 0.20
set rmargin at screen 0.80
tmarg = 0.9

h=0.0001


nL1=1
nS1=1
nL2=1
nS2=1
nS3=0
nS4=0

L1x[1]=0.0; L1T[1]=T1
S1x[1]=0.0; S1T[1]=T1
L2x[1]=1.0; L2T[1]=T2
S2x[1]=1.0; S2T[1]=T2


do for[i=nT:1:-1]{

  a0=0.0
  b0=0.0
  a1=0.0
  b1=0.0
  a2=G2-G1
  b2=0.0

  T = Tmin+i*dT

  set format x "%.1f"
  

  if(Teu<T && T<T1){

    xa0 = 0.001
    xb0 = 0.01

    delta = 10.0

    while( abs(delta)>0.001 ){

      f(x)=dGL(x)-dGS(xa0)

      while( abs(f(xb0))>0.001 ){
        df=(f(xb0+h)-f(xb0-h))/(2*h)
        xb0new = xb0-f(xb0)/df
        xb0 = xb0new
      }

      a0=dGL(xb0)
      b0=GL(xb0)-a0*xb0

      delta = (a0*xa0+b0) - GS(xa0)

      xa0 = xa0+delta*0.00001

    }

    nL1=nL1+1
    L1x[nL1] = xb0
    L1T[nL1] = T

    set arrow from L1x[nL1], L1T[nL1] to L1x[nL1-1], L1T[nL1-1] nohead

    nS1=nS1+1
    S1x[nS1] = xa0
    S1T[nS1] = T

    set arrow from S1x[nS1], S1T[nS1] to S1x[nS1-1], S1T[nS1-1] nohead

#    print T,"#1", a0, b0, xa0, xb0
  
  }

  if(Teu<T && T<T2){

    xa1 = 0.999
    xb1 = 0.995

    delta = 10.0

    while( abs(delta)>0.001 ){

      f(x)=dGL(x)-dGS(xa1)

      while( abs(f(xb1))>0.001 ){
        df=(f(xb1+h)-f(xb1-h))/(2*h)
        xb1new = xb1-f(xb1)/df
        xb1 = xb1new
      }

      a1=dGL(xb1)
      b1=GL(xb1)-a1*xb1

      delta = (a1*xa1+b1) - GS(xa1)

      xa1 = xa1-delta*0.00001

#      print a1, b1, xa1, xb1

    }

    nL2=nL2+1
    L2x[nL2] = xb1
    L2T[nL2] = T

    set arrow from L2x[nL2], L2T[nL2] to L2x[nL2-1], L2T[nL2-1] nohead


    nS2=nS2+1
    S2x[nS2] = xa1
    S2T[nS2] = T

    set arrow from S2x[nS2], S2T[nS2] to S2x[nS2-1], S2T[nS2-1] nohead


  }


  if(T<Teu){

    f(x)=dGS(x)-a2

    xa2 = 0.01
    while( abs(f(xa2))>0.001 ){
      df=(f(xa2+h)-f(xa2-h))/(2*h)
      xa2new = xa2-f(xa2)/df
      xa2 = xa2new
    }
    b2=GS(xa2)-a2*xa2

    xb2 = 0.99
    while( abs(f(xb2))>0.001 ){
      df=(f(xb2+h)-f(xb2-h))/(2*h)
      xb2new = xb2-f(xb2)/df
      xb2 = xb2new
    }

#    print T, xa2, xb2

    nS3=nS3+1
    S3x[nS3] = xa2
    S3T[nS3] = T
    S4x[nS3] = xb2
    S4T[nS3] = T

    if(nS3==1){
      set arrow from S3x[nS3], S3T[nS3] to S4x[nS3], S4T[nS3] nohead
    }else{
      set arrow from S3x[nS3], S3T[nS3] to S3x[nS3-1], S3T[nS3-1] nohead
      set arrow from S4x[nS3], S4T[nS3] to S4x[nS3-1], S4T[nS3-1] nohead
    }


  }


}

  plot 0.0 notitle

set output
set terminal wxt

reset
