############################################################
#                                                          #
#          Figure 10.14  "G of eutectic alloy"             #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################


#set terminal wxt size 600,600

set terminal png enhanced size 600,600
set output "fig10_14.png"

#set terminal postscript eps size 10cm,10cm
#set output "fig10_14.eps"


set parametric
set isosample 40,40

set view 65,72,1,1.5

set xyplane at -25000

set linetype 1 lc rgb "black" lw 0
set linetype 2 lc rgb "black" lw 1
set linetype 3 lc rgb "black" lw 2

R=8.314
G1=-17000.0
G2=-15000.0

T1=1000.0
T2=1200.0

epsS=20000.0
epsL=0.0

GS(x,T)=G1*(1.0-x)+G2*x+epsS*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x))
GL(x,T)=G1*(1.0-x)+G2*x+epsL*(1.0-x)*x+R*T*((1.0-x)*log(1.0-x)+x*log(x)) \
       +R*(T1-T)*(1.0-x)+R*(T2-T)*x

dGS(x,T)=-G1+G2+epsS*(1.0-x)-epsS*x+R*T*log(x/(1-x))
dGL(x,T)=-G1+G2+epsL*(1.0-x)-epsL*x+R*T*log(x/(1-x))+R*(T2-T1)

xrmin = 0.0
xrmax = 1.0
yrmin = 600.0
yrmax = 1200.0
zrmin = -25000.0
zrmax = -11000.0

set urange[0.0:1.0]

set xrange[xrmin:xrmax]
set yrange[yrmin:yrmax]
set zrange[zrmin:zrmax]

set xlabel "{/Arial x_B}"
set ylabel "{/Arial T(K)}"
set zlabel offset first 0,0,1000 "{/Arial G(J)}"

Teu=656.5

#array Temp[4] = [1150.0, 950.0, Teu, 500.0]
array Temp[3] = [1150.0, 900.0, Teu]

array a0[4]
array b0[4]
array xa0[4]
array xb0[4]
array a1[4]
array b1[4]
array xa1[4]
array xb1[4]
array a2[4]
array b2[4]
array xa2[4]
array xb2[4]


Tmax = 1300
Tmin = 600
dT = 1
nT = int((Tmax-Tmin)/dT)

array L1x[nT]
array L1T[nT]
array S1x[nT]
array S1T[nT]
array L2x[nT]
array L2T[nT]
array S2x[nT]
array S2T[nT]
array S3x[nT]
array S3T[nT]
array S4x[nT]
array S4T[nT]


h = 0.0001

do for[i=1:3]{

  a0w=0.0
  b0w=0.0
  a1w=0.0
  b1w=0.0
  a2w=G2-G1
  b2w=0.0

  T = Temp[i]

  set arrow 100+i*10   from xrmin, Temp[i], zrmin to xrmax, Temp[i], zrmin nohead
  set arrow 100+i*10+1 from xrmin, Temp[i], zrmax to xrmax, Temp[i], zrmax nohead
  set arrow 100+i*10+2 from xrmin, Temp[i], zrmin to xrmin, Temp[i], zrmax nohead
  set arrow 100+i*10+3 from xrmax, Temp[i], zrmin to xrmax, Temp[i], zrmax nohead

  if(Teu<=T && T<T1){

    xa0w = 0.01
    xb0w = 0.1

    delta = 10.0

    while( abs(delta)>0.001 ){

      f(x)=dGL(x,T)-dGS(xa0w,T)

      while( abs(f(xb0w))>0.001 ){
        df=(f(xb0w+h)-f(xb0w-h))/(2*h)
        xb0new = xb0w-f(xb0w)/df
        xb0w = xb0new
      }

      a0w=dGL(xb0w,T)
      b0w=GL(xb0w,T)-a0w*xb0w

      delta = (a0w*xa0w+b0w) - GS(xa0w,T)

      xa0w = xa0w+delta*0.00001

    }

#    print T,"#1", a0, b0, xa0, xb0
    a0[i] = a0w
    b0[i] = b0w
    xa0[i] = xa0w
    xb0[i] = xb0w

    set arrow 200+i*10 from xa0[i]-0.1, Temp[i], a0[i]*(xa0[i]-0.1)+b0[i] to xb0[i]+0.1, Temp[i], a0[i]*(xb0[i]+0.1)+b0[i] nohead linestyle 2
  
    set arrow 200+i*10+1 from xa0[i], Temp[i], GS(xa0[i],Temp[i]) to xa0[i], Temp[i], zrmin nohead
    set arrow 200+i*10+2 from xb0[i], Temp[i], GL(xb0[i],Temp[i]) to xb0[i], Temp[i], zrmin nohead

  }


  if(Teu<=T && T<T2){

    xa1w = 0.99
    xb1w = 0.95

    delta = 10.0

    while( abs(delta)>0.001 ){

      f(x)=dGL(x,T)-dGS(xa1w,T)

      while( abs(f(xb1w))>0.001 ){
        df=(f(xb1w+h)-f(xb1w-h))/(2*h)
        xb1new = xb1w-f(xb1w)/df
        xb1w = xb1new
      }

      a1w=dGL(xb1w,T)
      b1w=GL(xb1w,T)-a1w*xb1w

      delta = (a1w*xa1w+b1w) - GS(xa1w,T)

      xa1w = xa1w-delta*0.00001

#      print a1, b1, xa1, xb1

    }

    a1[i] = a1w
    b1[i] = b1w
    xa1[i] = xa1w
    xb1[i] = xb1w

    set arrow 300+i*10 from xa1[i]+0.1, Temp[i], a1[i]*(xa1[i]+0.1)+b1[i] to xb1[i]-0.1, Temp[i], a1[i]*(xb1[i]-0.1)+b1[i] nohead linestyle 2
  
    set arrow 300+i*10+1 from xa1[i], Temp[i], GS(xa1[i],Temp[i]) to xa1[i], Temp[i], zrmin nohead
    set arrow 300+i*10+2 from xb1[i], Temp[i], GL(xb1[i],Temp[i]) to xb1[i], Temp[i], zrmin nohead


  }

  if(T<Teu){

    f(x)=dGS(x,T)-a2w

    xa2w = 0.01
    while( abs(f(xa2w))>0.001 ){
      df=(f(xa2w+h)-f(xa2w-h))/(2*h)
      xa2new = xa2w-f(xa2w)/df
      xa2w = xa2new
    }
    b2w=GS(xa2w,T)-a2w*xa2w

    xb2w = 0.99
    while( abs(f(xb2w))>0.001 ){
      df=(f(xb2w+h)-f(xb2w-h))/(2*h)
      xb2new = xb2w-f(xb2w)/df
      xb2w = xb2new
    }

    a2[i] = a2w
    b2[i] = b2w
    xa2[i] = xa2w
    xb2[i] = xb2w

#    set arrow from xa2, GS(xa2)-1500 to xa2, GS(xa2)
#    set arrow from xb2, GS(xb2)-1500 to xb2, GS(xb2)

    set arrow 400+i*10 from xa2[i]-0.1, Temp[i], a2[i]*(xa2[i]-0.1)+b2[i] to xb2[i]+0.1, Temp[i], a2[i]*(xb2[i]+0.1)+b2[i] nohead linestyle 2
  
    set arrow 400+i*10+1 from xa2[i], Temp[i], GS(xa2[i],Temp[i]) to xa2[i], Temp[i], zrmin nohead
    set arrow 400+i*10+2 from xb2[i], Temp[i], GL(xb2[i],Temp[i]) to xb2[i], Temp[i], zrmin nohead


#      print a2, b2, xa2, xb2
  }




}


nL1=1
nS1=1
nL2=1
nS2=1
nS3=0
nS4=0

L1x[1]=0.0; L1T[1]=T1
S1x[1]=0.0; S1T[1]=T1
L2x[1]=1.0; L2T[1]=T2
S2x[1]=1.0; S2T[1]=T2

do for[i=nT:1:-1]{

  a0w=0.0
  b0w=0.0
  a1w=0.0
  b1w=0.0
  a2w=G2-G1
  b2w=0.0

  T = Tmin+i*dT

  set format x "%.1f"
  

  if(Teu<T && T<T1){

    xa0w = 0.001
    xb0w = 0.01

    delta = 10.0

    while( abs(delta)>0.001 ){

      f(x)=dGL(x,T)-dGS(xa0w,T)

      while( abs(f(xb0w))>0.001 ){
        df=(f(xb0w+h)-f(xb0w-h))/(2*h)
        xb0new = xb0w-f(xb0w)/df
        xb0w = xb0new
      }

      a0w=dGL(xb0w,T)
      b0w=GL(xb0w,T)-a0w*xb0w

      delta = (a0w*xa0w+b0w) - GS(xa0w,T)

      xa0w = xa0w+delta*0.00001

    }

    nL1=nL1+1
    L1x[nL1] = xb0w
    L1T[nL1] = T

    set arrow from L1x[nL1], L1T[nL1] ,zrmin to L1x[nL1-1], L1T[nL1-1], zrmin linetype 3 nohead

    nS1=nS1+1
    S1x[nS1] = xa0w
    S1T[nS1] = T

    set arrow from S1x[nS1], S1T[nS1], zrmin to S1x[nS1-1], S1T[nS1-1], zrmin linetype 3 nohead

#    print T,"#1", a0, b0, xa0, xb0
  
  }

  if(Teu<T && T<T2){

    xa1w = 0.999
    xb1w = 0.995

    delta = 10.0

    while( abs(delta)>0.001 ){

      f(x)=dGL(x,T)-dGS(xa1w,T)

      while( abs(f(xb1w))>0.001 ){
        df=(f(xb1w+h)-f(xb1w-h))/(2*h)
        xb1new = xb1w-f(xb1w)/df
        xb1w = xb1new
      }

      a1w=dGL(xb1w,T)
      b1w=GL(xb1w,T)-a1w*xb1w

      delta = (a1w*xa1w+b1w) - GS(xa1w,T)

      xa1w = xa1w-delta*0.00001

#      print a1, b1, xa1, xb1

    }

    nL2=nL2+1
    L2x[nL2] = xb1w
    L2T[nL2] = T

    set arrow from L2x[nL2], L2T[nL2], zrmin to L2x[nL2-1], L2T[nL2-1], zrmin linetype 3 nohead


    nS2=nS2+1
    S2x[nS2] = xa1w
    S2T[nS2] = T

    set arrow from S2x[nS2], S2T[nS2], zrmin to S2x[nS2-1], S2T[nS2-1], zrmin linetype 3 nohead


  }


  if(T<Teu){       

    f(x)=dGS(x,T)-a2w

    xa2w = 0.01
    while( abs(f(xa2w))>0.001 ){
      df=(f(xa2w+h)-f(xa2w-h))/(2*h)
      xa2new = xa2w-f(xa2w)/df
      xa2w = xa2new
    }
    b2=GS(xa2w,T)-a2w*xa2w

    xb2w = 0.99
    while( abs(f(xb2w))>0.001 ){
      df=(f(xb2w+h)-f(xb2w-h))/(2*h)
      xb2new = xb2w-f(xb2w)/df
      xb2w = xb2new
    }

#    print T, xa2, xb2

    nS3=nS3+1
    S3x[nS3] = xa2w
    S3T[nS3] = T
    S4x[nS3] = xb2w
    S4T[nS3] = T

    if(nS3==1){
      set arrow from S3x[nS3], S3T[nS3], zrmin to S4x[nS3], S4T[nS3], zrmin linetype 3 nohead
    }else{
      set arrow from S3x[nS3], S3T[nS3], zrmin to S3x[nS3-1], S3T[nS3-1], zrmin linetype 3 nohead
      set arrow from S4x[nS3], S4T[nS3], zrmin to S4x[nS3-1], S4T[nS3-1], zrmin linetype 3 nohead
    }


  }


}


  splot u, Temp[1], GS(u,Temp[1]) notitle linetype 3, \
        u, Temp[1], GL(u,Temp[1]) notitle linetype 3, \
        u, Temp[2], GS(u,Temp[2]) notitle linetype 3, \
        u, Temp[2], GL(u,Temp[2]) notitle linetype 3, \
        u, Temp[3], GS(u,Temp[3]) notitle linetype 3, \
        u, Temp[3], GL(u,Temp[3]) notitle linetype 3
#, \
#        u, Temp[4], GS(u,Temp[4]) notitle linetype 2, \
#        u, Temp[4], GL(u,Temp[4]) notitle linetype 2


set output
set terminal wxt

reset
