############################################################
#                                                          #
#          Figure 10.8  "G of regular solution"            #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################
#

R=8.31
G1=-5000.0
G2=-7000.0
T=1000.0


# solid solution
eps1=-10000.0
GS1(x)=G1*(1.0-x)+G2*x+eps1*x*(1.0-x)+R*T*(x*log(x)+(1.0-x)*log(1.0-x))
dgs1(x)=-G1+G2+eps1*(1.0-2.0*x)+R*T*log(x/(1.0-x))

# ideal solution
eps2=0.0
GS2(x)=G1*(1.0-x)+G2*x+eps2*x*(1.0-x)+R*T*(x*log(x)+(1.0-x)*log(1.0-x))
dgs2(x)=-G1+G2+eps2*(1.0-2.0*x)+R*T*log(x/(1.0-x))

# immissible solution
eps3=25000.0
GS3(x)=G1*(1.0-x)+G2*x+eps3*x*(1.0-x)+R*T*(x*log(x)+(1.0-x)*log(1.0-x))
dgs3(x)=-G1+G2+eps3*(1.0-2.0*x)+R*T*log(x/(1.0-x))


x1=0.45

a1=dgs1(x1)
b1=GS1(x1)-a1*x1
muA1=a1*0.0+b1
muB1=a1*1.0+b1


a2=dgs2(x1)
b2=GS2(x1)-a2*x1
muA2=a2*0.0+b2
muB2=a2*1.0+b2

a3=dgs3(x1)
b3=GS3(x1)-a3*x1


a4=G2-G1
h=0.001
f(x)=dgs3(x)-a4

xa1=0.01
while( abs(f(xa1))>0.00001 ){
  df=(f(xa1+h)-f(xa1-h))/(2*h)
  xa2=xa1-f(xa1)/df
  xa1=xa2
}
b4=GS3(xa1)-a4*xa1

xb1=0.99
while( abs(f(xb1))>0.00001 ){
  df=(f(xb1+h)-f(xb1-h))/(2*h)
  xb2=xb1-f(xb1)/df
  xb1=xb2
}
#b4=GS3(xb1)-a4*xb1

#set label 98 sprintf("xa=%10.5f", xa1) at graph 0.02,0.10
#set label 99 sprintf("xb=%10.5f", xb1) at graph 0.02,0.05
#x1=0.0699406  
#x2=0.930059


set xrange[0.0:1.0]
set yrange[-20000:-4000]

set xlabel "{/Arial x_B}"
set ylabel "{/Arial G}"

set label 1 at first 0.5, GS1(0.5)+500 sprintf("{/Arial =%0.0f}", eps1)
#set label 1 at first 0.5, GS1(0.5)+500 sprintf("{/Symbol e}{/Arial =%0.0f}", eps1)
set label 2 at first 0.5, GS2(0.5)+500 sprintf("{/Arial =%0.0f}", eps2)
#set label 2 at first 0.5, GS2(0.5)+500 sprintf("{/Symbol e}{/Arial =%0.0f}", eps2)
set label 3 at first 0.5, GS3(0.5)+500 sprintf("{/Arial =%0.0f}", eps3)
#set label 3 at first 0.5, GS3(0.5)+500 sprintf("{/Symbol e}{/Arial =%0.0f}", eps3)

set arrow from 0+0.1, muA1-1800 to 0, muA1
set label 11 at first 0+0.1, muA1-2000 sprintf("{/Arial _A=%0.0f}", muA1)
#set label 11 at first 0+0.1, muA1-2000 sprintf("{/Symbol m}{/Arial _A=%0.0f}", muA1)
set arrow from 1-0.2, muB1-1800 to 1, muB1
set label 12 at first 1-0.2, muB1-2000 sprintf("{/Arial _B=%0.0f}", muB1)
#set label 12 at first 1-0.2, muB1-2000 sprintf("{/Symbol m}{/Arial _B=%0.0f}", muB1)

set arrow from 0+0.1, muA2-1800 to 0, muA2
set label 21 at first 0+0.1, muA2-2000 sprintf("{/Arial _A=%0.0f}", muA2)
#set label 21 at first 0+0.1, muA2-2000 sprintf("{/Symbol m}{/Arial _A=%0.0f}", muA2)
set arrow from 1-0.2, muB2-1800 to 1, muB2
set label 22 at first 1-0.2, muB2-2000 sprintf("{/Arial _B=%0.0f}", muB2)
#set label 22 at first 1-0.2, muB2-2000 sprintf("{/Symbol m}{/Arial _B=%0.0f}", muB2)

set arrow from x1,GS1(x1)-2000 to x1,GS1(x1)
set label 31 at first x1, GS1(x1)-2200 sprintf("x_B=%0.2f", x1)


plot GS1(x) notitle lw 1 lc rgb "black" dt 1, \
     GS2(x) notitle lw 1 lc rgb "black" dt 1, \
     GS3(x) notitle lw 1 lc rgb "black" dt 1, \
     a1*x+b1 notitle lw 1 lc rgb "black" dt 1, \
     a2*x+b2 notitle lw 1 lc rgb "black" dt 1

set terminal png enhanced
set output "fig10_8.png"

#set terminal postscript eps
#set output "fig10_8.eps"

replot

set output
set terminal wxt

reset
