############################################################
#                                                          #
#          Figure 10.9 G of regular solution"              #
#            Script for Gnuplot(ver. 5.2)                  #
#                                                          #
#   An Introduction to the Thermodynamics in Materials     #
#                  by Tadahiko Masaki CORONA PUB. CO.,LTD  #
#                                (ISBN 978-4-339-06648-7)  #
#                                                          #
############################################################


R=8.31
G1=-5000.0
G2=-7000.0
T=1000.0

# immissible solution
eps3=25000.0
GS3(x)=G1*(1.0-x)+G2*x+eps3*x*(1.0-x)+R*T*(x*log(x)+(1.0-x)*log(1.0-x))
dgs3(x)=-G1+G2+eps3*(1.0-2.0*x)+R*T*log(x/(1.0-x))


x1=0.45

a3=dgs3(x1)
b3=GS3(x1)-a3*x1
muA3=a3*0.0+b3
muB3=a3*1.0+b3

a4=G2-G1
h=0.001
f(x)=dgs3(x)-a4


xa1=0.01
while( abs(f(xa1))>0.00001 ){
  df=(f(xa1+h)-f(xa1-h))/(2*h)
  xa2=xa1-f(xa1)/df
  xa1=xa2
}
b4=GS3(xa1)-a4*xa1
muA4=a4*0.0+b4
muB4=a4*1.0+b4

xb1=0.99
while( abs(f(xb1))>0.00001 ){
  df=(f(xb1+h)-f(xb1-h))/(2*h)
  xb2=xb1-f(xb1)/df
  xb1=xb2
}

#b4=GS3(xb1)-a4*xb1

#set label 98 sprintf("xa=%10.5f", xa1) at graph 0.02,0.10
#set label 99 sprintf("xb=%10.5f", xb1) at graph 0.02,0.05
#x1=0.0699406  
#x2=0.930059

#set label 99 sprintf("G(0.45)=%0.0f", a4*x1+b4)  at graph 0.02,0.05

set xrange[0.0:1.0]
set yrange[-8000:-4500]

set xlabel "{/Arial x_B}"
set ylabel "{/Arial G}"

set label 3 at first 0.5, GS3(0.5)+500 sprintf("{/Arial =%0.0f}", eps3)
#set label 3 at first 0.5, GS3(0.5)+500 sprintf("{/Symbol e}{/Arial =%0.0f}", eps3)

set arrow from 0+0.1, muA3+200 to 0, muA3
set label 11 at first 0+0.1, muA3+220 sprintf("{/Arial _A=%0.0f}", muA3)
#set label 11 at first 0+0.1, muA3+220 sprintf("{/Symbol m}{/Arial _A=%0.0f}", muA3)
set arrow from 1-0.2, muB3+1000 to 1, muB3
set label 12 at first 1-0.2, muB3+1050 sprintf("{/Arial _B=%0.0f}", muB3)
#set label 12 at first 1-0.2, muB3+1050 sprintf("{/Symbol m}{/Arial _B=%0.0f}", muB3)

set arrow from 0+0.1, muA4+200 to 0, muA4
set label 21 at first 0+0.1, muA4+220 sprintf("{/Arial _A=%0.0f}", muA4)
#set label 21 at first 0+0.1, muA4+220 sprintf("{/Symbol m}{/Arial _A=%0.0f}", muA4)
set arrow from 1-0.2, muB4+1000 to 1, muB4
set label 22 at first 1-0.2, muB4+1050 sprintf("{/Arial _B=%0.0f}", muB4)
#set label 22 at first 1-0.2, muB4+1050 sprintf("{/Symbol m}{/Arial _B=%0.0f}", muB4)

set arrow from x1,GS3(x1)-500 to x1,GS3(x1)
set label 31 at first x1-0.05, GS3(x1)-550 sprintf("x_B=%0.2f", x1)

set arrow from xa1,GS3(xa1)-500 to xa1,GS3(xa1)
set label 32 at first xa1-0.05, GS3(xa1)-550 sprintf("x_B=%0.2f", xa1)

set arrow from xb1,GS3(xb1)-500 to xb1,GS3(xb1)
set label 33 at first xb1-0.05, GS3(xb1)-550 sprintf("x_B=%0.2f", xb1)

set label 41 at first 0.7, -5500 "{/Arial (1)}"
set label 42 at first 0.7, -7100 "{/Arial (2)}"

plot GS3(x) notitle lw 1 lc rgb "black" dt 1, \
     a3*x+b3 notitle lw 1 lc rgb "black" dt 1, \
     a4*x+b4 notitle lw 1 lc rgb "black" dt 1

set terminal png enhanced
set output "fig10_9.png"

#set terminal postscript eps
#set output "fig10_9.eps"

replot

set output
set terminal wxt

reset
